@@ -126,6 +126,7 @@ bike_station_dates <- function (bikedb, city)
 #' @export
 #'
 #' @examples
+#' \dontrun{
 #' data_dir <- tempdir ()
 #' bike_write_test_data (data_dir = data_dir)
 #' bikedb <- file.path (data_dir, 'testdb')
@@ -137,6 +138,7 @@ bike_station_dates <- function (bikedb, city)
 #' bike_rm_db (bikedb)
 #' # don't forget to remove real data!
 #' # file.remove (list.files ('.', pattern = '.zip'))
+#' }
 bike_stored_files <- function (bikedb, city)
 {
     if (missing (bikedb))
@@ -216,6 +218,7 @@ bike_db_totals <- function (bikedb, trips = TRUE, city)
 #' @export
 #'
 #' @examples
+#' \dontrun{
 #' data_dir <- tempdir ()
 #' bike_write_test_data (data_dir = data_dir)
 #' # or download some real data!
@@ -231,6 +234,7 @@ bike_db_totals <- function (bikedb, trips = TRUE, city)
 #' bike_rm_db (bikedb)
 #' # don't forget to remove real data!
 #' # file.remove (list.files (data_dir, pattern = '.zip'))
+#'}
 bike_latest_files <- function (bikedb)
 {
     if (missing (bikedb))
@@ -243,6 +247,9 @@ bike_latest_files <- function (bikedb)
     cities <- unique (files$city)
     DBI::dbDisconnect (db)
 
+    files <- files [files$city != "mn", ]
+    cities <- cities [cities != "mn"]
+
     latest_files <- rep (TRUE, length (cities))
     names (latest_files) <- cities
     for (i in seq (cities))
