@@ -17,6 +17,7 @@
 
 #include "sqlite3db-utils.h"
 
+namespace stns {
 int import_to_station_table (sqlite3 * dbcon,
     std::map <std::string, std::string> stationqry);
 
@@ -24,5 +25,7 @@ std::map <std::string, std::string> get_bo_stn_table (sqlite3 * dbcon);
 std::map <std::string, std::string> get_dc_stn_table (sqlite3 * dbcon);
 std::unordered_set <std::string> get_stn_ids (sqlite3 * dbcon, std::string ci);
 
+} // end namespace stns
+
 int rcpp_import_stn_df (const char * bikedb, Rcpp::DataFrame stn_data,
         std::string city);
