@@ -18,6 +18,10 @@
 
 #define BUFFER_SIZE 512
 
+namespace db_utils {
+
 int get_max_trip_id (sqlite3 * dbcon);
 int get_max_stn_id (sqlite3 * dbcon);
 int get_stn_table_size (sqlite3 * dbcon);
+
+} // end namespace db_utils
